<?php

/*
Plugin Name: NATS Code
Plugin URI: http://wiki.toomuchmedia.com/index.php/NATS_Code_Wordpress_Plugin
Description: Allows you to insert NATS tracking codes into Wordpress posts.
Version: 0.2.4
Author: Too Much Media
Author URI: http://www.toomuchmedia.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

/* Start main important code */
function natscode_filter($post_text) {
	
	/* find all instances of [nats|something] or [nats] and replace them with the appropriate nats code */
	$post_text = preg_replace_callback('/\[(nats[^]]*)]/','natscode_filter_callback',$post_text);

	return $post_text;
}

function natscode_filter_links($links){
	if(!count($links)) return $links;
	if(substr($_SERVER['REQUEST_URI'],0,9) =='/wp-admin') return $links;
	foreach($links as $key=>$link)
	{
		$links[$key]->link_url = preg_replace_callback('/(NATSCODE[a-zA-Z0-9,;:.|]*)/','natscode_filter_callback',$link->link_url);
	}
	return $links;
}

function natscode_filter_callback($replace) {

	static $natsoptions = Array();
	$nats = '';
	if(!count($natsoptions))
	{
		$natsoptions['default_code'] = get_option('natscode_default_code');
		$natsoptions['affiliate'] = get_option('natscode_affiliate');
		$natsoptions['sites'] = get_option('natscode_sites');
	}
	if(!$natsoptions['affiliate']) $nats = $_GET['nats']; // query string comes first
	if(!$nats && $natsoptions['affiliate']) {
		list(,$secondarg) = explode('|',$replace[1]);
		if(substr($secondarg,0,5) == 'site:') {
			$short = substr($secondarg,5);
			if($natsoptions['sites'][$short]['natscode'])
				$nats = $natsoptions['sites'][$short]['natscode'];
		}
	}
	if(!$nats) {	
		list(,$defaultnats) = explode('|',$replace[1]);
		if(substr($defaultnats,0,5) != 'site:') $nats = $defaultnats; // inline nats code comes next
	}
	if(!$nats) {
		$nats = $natsoptions['default_code']; // default code in admin comes last
	}

	return $nats;
}

function natscode_link($link){
	static $natsoptions = Array();
	if(!count($natsoptions))
	{
		$natsoptions['affiliate'] = get_option('natscode_affiliate');
	}
	if($_GET['nats'] && !$natsoptions['affiliate']){
		$url = parse_url($link);
		$vars = Array();
		parse_str($url['query'],$vars);
		$vars['nats'] = $_GET['nats'];
		$query = htmlentities(http_build_query($vars));
		$link = "$url[scheme]://$url[host]$url[path]?$query";
	}
	return $link;
}

/* End main important code */

function natscode_options() { 
	$sites = get_option('natscode_sites');
	if(!is_array($sites) || !count($sites)) $sites = Array();
	if($_POST['natscode_save']){
		update_option('natscode_default_code',$_POST['natscode_default_code']);
		update_option('natscode_affiliate',$_POST['natscode_affiliate']);
		echo '<div class="updated"><p>NATS code settings updated.</p></div>';
	}
		
	if($_POST['natscode_site_add']) {
		$adderrors = Array();
		if(!$_POST['natscode_site_new_short']) {
			$adderrors[] = "Short name is required";
		}
		if(!preg_match('/^[A-Za-z0-9_]*$/',$_POST['natscode_site_new_short'])) {
			$adderrors[] = "Short name should only be numbers, letters, and underscores";
		}
		if(!$_POST['natscode_site_new_natscode']) {
			$adderrors[] = "NATS Code is required";
		}
		if(in_array($_POST['natscode_site_new_short'], array_keys($sites))) {
			$adderrors[] = "Short name is already in use";
		}
		if(!count($adderrors))
		{
			$adderror = 0;
			$sites[$_POST['natscode_site_new_short']] = Array('desc' => htmlentities(stripslashes($_POST['natscode_site_new_desc'])), 'natscode' => $_POST['natscode_site_new_natscode']);
			update_option('natscode_sites', $sites);
		}
		else
			$adderror = 1;
	
	}
	if($_POST['natscode_site_delete']) {
		foreach($_POST['natscode_site_delete'] as $short=>$val)
		{
			unset($sites[$short]);
		}
		update_option('natscode_sites', $sites);
	}
	if($_POST['natscode_site_edit']) {
		$editerrors = Array();
		foreach($_POST['natscode_site_edit'] as $short=>$val)
		{
			$sites[$short] = Array('desc'=> htmlentities(stripslashes($_POST['natscode_site_desc'][$short])), 'natscode' => $_POST['natscode_site_natscode'][$short] );
			
		}
		update_option('natscode_sites', $sites);
	}
	?>
	<div class="wrap">
	<h2>NATS Code Options</h2>
	<form method="post" id="natscode_options">
		<?php wp_nonce_field('update-options'); ?>
		<fieldset class="options">
		<table width="100%" cellspacing="2" cellpadding="5" class="editform">
			<tr valign="top">
				<th width="33%" scope="row">Default NATS Code:</th>
				<td><input name="natscode_default_code" type="text" id="natscode_default_code" value="<?php echo get_option('natscode_default_code') ;?>" size="15" />
				<br />Sets the default NATS code to use if there is no NATS code in the query string, and no NATS code is specified in line.
				<?php if(!get_option('natscode_default_code')) { ?>
				<br/><strong>You do not currently have a default NATS code set</strong>. If you do not have a NATS code set inline for every surfer link, you may
				send surfers to a blank page!<?php } ?>
				</td>
			</tr>
			<tr valign="top">
				<th width="33%" scope="row">Affiliate:</th>
				<td>
				<input name="natscode_affiliate" type="hidden" value="0"/>
				<input name="natscode_affiliate" type="checkbox" id="natscode_affiliate" value="1" <?php if(get_option('natscode_affiliate')) echo "CHECKED" ;?>/>
				<br/><strong>If you are an affiliate promoting other people's sites, check this box</strong>
				<br />If selected, we will ignore any nats code in the query string, and allow you to set up different nats codes for different sites. 
				</td>
			</tr>
		</table>
		<p class="submit"><input type="submit" name="natscode_save" value="Save" /></p>
		</fieldset>
	</form>
	<?php if(get_option('natscode_affiliate')) { ?>
	<h2>NATS Site Codes</h2>
	<form method="post" id="natscode_sitecodes">
		<?php wp_nonce_field('update-options'); ?>
		<fieldset class="options">
			<p>Allows you to specify a list of nats codes to use for different sites. If you choose "foo" as the short name, you can use that nats code with "[nats|site:foo]"</p>
			<?php $sites = get_option('natscode_sites'); if(!is_array($sites)) $sites = Array();?>
			<table width="100%" cellspacing="2" cellpadding="5" class="editform">
			<tr style="text-align:center">
				<th>Short Name</th> <th>Description</th> <th>NATS Code</th> <th>&nbsp;</th>
			</tr>
				<?php 
				if(count($sites)) {
					foreach($sites as $short => $site) {
						echo "<tr style='text-align:center'>";
						echo "<td>$short</td>";
						echo "<td><input name='natscode_site_desc[$short]' type='text' value='".($edit_error[$short]?$_POST['natscode_site_desc'][$short]:$site['desc'])."' size='15'/></td>";
						echo "<td><input name='natscode_site_natscode[$short]' type='text' value='".($edit_error[$short]?$_POST['natscode_site_natscode'][$short]:$site['natscode'])."' size='15'/></td>";
						echo "<td><input name='natscode_site_edit[$short]' type=submit value='Edit'/>";
						echo "<input  name='natscode_site_delete[$short]' type=submit value='Delete'/>";
						if($edit_error[$short]) echo " See errors below";
						echo "</td>";
						echo "</tr>\n";
					}
				}
				?>
				<tr style="text-align:center">
					<td><input name="natscode_site_new_short" type="text" size="15" <?php if($adderror) echo "value='$_POST[natscode_site_new_short]'";?> /></td>
					<td><input name="natscode_site_new_desc" type="text" size="15" <?php if($adderror) echo "value='$_POST[natscode_site_new_desc]'";?> /></td> 
					<td><input name="natscode_site_new_natscode" type="text" size="15" <?php if($adderror) echo "value='$_POST[natscode_site_new_natscode]'";?> /></td>
					<td><input type="submit" name="natscode_site_add" value="Add New"/></td>
				</tr>
			</table>
			<?php 
			if($adderror) {
				foreach($adderrors as $error) {
					echo "<p style='font-color:red'>$error</p>";
				}
			}
			if($editerror) {
				foreach($editerrors as $error) {
					echo "<p style='font-color:red'>$error</p>";
				}
			}
			?>	
		</fieldset>
	</form>
	<?php } ?>
	</div>
	<?php
}
		
function natscode_adminmenu(){
	add_options_page('NATS Code Options', 'NATS Code', 9, 'natscode.php', 'natscode_options');
}

add_filter('the_content', 'natscode_filter', 2);
add_filter('wp_list_bookmarks', 'natscode_filter', 20);
add_filter('widget_text', 'natscode_filter', 20);
add_filter('comment_reply_link', 'natscode_link', 20);
add_filter('feed_link', 'natscode_link', 20);
add_filter('day_link', 'natscode_link', 20);
add_filter('author_feed_link', 'natscode_link', 20);
add_filter('author_link', 'natscode_link', 20);
add_filter('month_link', 'natscode_link', 20);
add_filter('page_link', 'natscode_link', 20);
add_filter('post_link', 'natscode_link', 20);
add_filter('year_link', 'natscode_link', 20);
add_filter('tag_link', 'natscode_link', 20);
add_filter('category_link', 'natscode_link', 20);
add_filter('get_bookmarks','natscode_filter_links',20);
add_action('admin_menu','natscode_adminmenu',1);
if($_GET['nats'] && (!$_COOKIE['natswp'] || $_COOKIE['natswp'] != $_GET['nats'])){
	setcookie('natswp',$_GET['nats'], time()+36000);
	 $_COOKIE['natswp'] = $_GET['nats'];
}
if($_COOKIE['natswp'] && !$_GET['nats']){
	$_GET['nats'] = $_COOKIE['natswp'];
}
?>